"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dumpDevice = void 0;
const eufy_security_client_1 = require("eufy-security-client");
const dumpDevice = (device, schemaVersion) => {
    const base = {
        name: device.getPropertyValue(eufy_security_client_1.PropertyName.Name),
        model: device.getPropertyValue(eufy_security_client_1.PropertyName.Model),
        serialNumber: device.getPropertyValue(eufy_security_client_1.PropertyName.SerialNumber),
        hardwareVersion: device.getPropertyValue(eufy_security_client_1.PropertyName.HardwareVersion),
        softwareVersion: device.getPropertyValue(eufy_security_client_1.PropertyName.SoftwareVersion),
        stationSerialNumber: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceStationSN),
        enabled: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceEnabled),
        state: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceState),
        battery: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceBattery),
        batteryTemperature: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceBatteryTemp),
        batteryLow: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceBatteryLow),
        lastChargingDays: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLastChargingDays),
        lastChargingTotalEvents: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLastChargingTotalEvents),
        lastChargingRecordedEvents: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLastChargingRecordedEvents),
        lastChargingFalseEvents: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLastChargingFalseEvents),
        batteryUsageLastWeek: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceBatteryUsageLastWeek),
        motionDetected: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetected),
        personDetected: device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePersonDetected),
        personName: device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePersonName),
        soundDetected: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetected),
        petDetected: device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePetDetected),
        cryingDetected: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceCryingDetected),
        ringing: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRinging),
        locked: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLocked),
        antitheftDetection: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAntitheftDetection),
        autoNightvision: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoNightvision),
        motionDetection: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetection),
        soundDetection: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetection),
        petDetection: device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePetDetection),
        rtspStream: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRTSPStream),
        watermark: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWatermark),
        lockStatus: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLockStatus),
        motionSensorPIREvent: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionSensorPIREvent),
        wifiRSSI: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWifiRSSI),
        pictureUrl: device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePictureUrl),
        sensorOpen: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSensorOpen),
        sensorChangeTime: device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSensorChangeTime),
    };
    if (schemaVersion == 0) {
        base.ledStatus = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceStatusLed);
        return base;
    }
    const device1 = base;
    device1.type = device.getPropertyValue(eufy_security_client_1.PropertyName.Type);
    if (schemaVersion <= 2) {
        return device1;
    }
    const device3 = device1;
    device3.motionDetectionType = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionType);
    device3.motionTracking = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionTracking);
    device3.soundDetectionType = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetectionType);
    device3.light = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLight);
    device3.microphone = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMicrophone);
    device3.speaker = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSpeaker);
    device3.speakerVolume = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSpeakerVolume);
    device3.ringtoneVolume = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingtoneVolume);
    device3.audioRecording = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAudioRecording);
    device3.powerSource = device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePowerSource);
    device3.powerWorkingMode = device.getPropertyValue(eufy_security_client_1.PropertyName.DevicePowerWorkingMode);
    device3.recordingEndClipMotionStops = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRecordingEndClipMotionStops);
    device3.recordingClipLength = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRecordingClipLength);
    device3.recordingRetriggerInterval = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRecordingRetriggerInterval);
    device3.videoStreamingQuality = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoStreamingQuality);
    device3.videoRecordingQuality = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoRecordingQuality);
    device3.videoWDR = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoWDR);
    device3.lightSettingsEnable = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsEnable);
    device3.lightSettingsBrightnessManual = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsBrightnessManual);
    device3.lightSettingsBrightnessMotion = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsBrightnessMotion);
    device3.lightSettingsBrightnessSchedule = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsBrightnessSchedule);
    device3.lightSettingsMotionTriggered = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsMotionTriggered);
    device3.lightSettingsMotionTriggeredDistance = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsMotionTriggeredDistance);
    device3.lightSettingsMotionTriggeredTimer = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsMotionTriggeredTimer);
    device3.chimeIndoor = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChimeIndoor);
    device3.chimeHomebase = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChimeHomebase);
    device3.chimeHomebaseRingtoneVolume = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChimeHomebaseRingtoneVolume);
    device3.chimeHomebaseRingtoneType = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChimeHomebaseRingtoneType);
    device3.notificationType = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationType);
    device3.rotationSpeed = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRotationSpeed);
    device3.notificationPerson = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationPerson);
    device3.notificationPet = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationPet);
    device3.notificationAllOtherMotion = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationAllOtherMotion);
    device3.notificationCrying = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationCrying);
    device3.notificationAllSound = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationAllSound);
    device3.notificationIntervalTime = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationIntervalTime);
    device3.notificationRing = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationRing);
    device3.notificationMotion = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationMotion);
    if (schemaVersion === 3) {
        device3.motionDetectionSensivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivity);
        device3.soundDetectionSensivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetectionSensitivity);
        return device3;
    }
    const device4 = device3;
    device4.chirpVolume = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChirpVolume);
    device4.chirpTone = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChirpTone);
    device4.motionDetectionSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivity);
    device4.soundDetectionSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetectionSensitivity);
    device4.videoHdr = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoHDR);
    device4.videoDistortionCorrection = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoDistortionCorrection);
    device4.videoRingRecord = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoRingRecord);
    device4.statusLed = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceStatusLed);
    device4.rtspStreamUrl = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRTSPStreamUrl);
    device4.chargingStatus = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceChargingStatus);
    device4.wifiSignalLevel = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWifiSignalLevel);
    if (schemaVersion <= 4) {
        return device4;
    }
    const device5 = device4;
    device5.nightvision = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNightvision);
    device5.batteryIsCharging = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceBatteryIsCharging);
    if (schemaVersion <= 5) {
        return device5;
    }
    const device6 = device5;
    device6.motionDetectionRange = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionRange);
    device6.motionDetectionRangeStandardSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionRangeStandardSensitivity);
    device6.motionDetectionRangeAdvancedLeftSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionRangeAdvancedLeftSensitivity);
    device6.motionDetectionRangeAdvancedMiddleSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionRangeAdvancedMiddleSensitivity);
    device6.motionDetectionRangeAdvancedRightSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionRangeAdvancedRightSensitivity);
    device6.motionDetectionTestMode = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionTestMode);
    device6.motionTrackingSensitivity = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionTrackingSensitivity);
    device6.motionAutoCruise = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionAutoCruise);
    device6.motionOutOfViewDetection = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionOutOfViewDetection);
    device6.lightSettingsColorTemperatureManual = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsColorTemperatureManual);
    device6.lightSettingsColorTemperatureMotion = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsColorTemperatureMotion);
    device6.lightSettingsColorTemperatureSchedule = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsColorTemperatureSchedule);
    device6.lightSettingsMotionActivationMode = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLightSettingsMotionActivationMode);
    device6.videoNightvisionImageAdjustment = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoNightvisionImageAdjustment);
    device6.videoColorNightvision = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceVideoColorNightvision);
    device6.autoCalibration = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoCalibration);
    if (schemaVersion <= 8) {
        return device6;
    }
    const device7 = device6;
    device7.lockSettingsAutoLock = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoLock);
    device7.lockSettingsAutoLockTimer = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoLockTimer);
    device7.lockSettingsAutoLockSchedule = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoLockSchedule);
    device7.lockSettingsAutoLockScheduleStartTime = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoLockScheduleStartTime);
    device7.lockSettingsAutoLockScheduleEndTime = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceAutoLockScheduleEndTime);
    device7.lockSettingsOneTouchLocking = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceOneTouchLocking);
    device7.lockSettingsWrongTryProtection = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWrongTryProtection);
    device7.lockSettingsWrongTryAttempts = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWrongTryAttempts);
    device7.lockSettingsWrongTryLockdownTime = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceWrongTryLockdownTime);
    device7.lockSettingsScramblePasscode = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceScramblePasscode);
    device7.lockSettingsSound = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSound);
    device7.lockSettingsNotification = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotification);
    device7.lockSettingsNotificationUnlocked = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationUnlocked);
    device7.lockSettingsNotificationLocked = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationLocked);
    if (schemaVersion <= 9) {
        return device7;
    }
    const device8 = device7;
    device8.notificationRadarDetector = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceNotificationRadarDetector);
    device8.continuousRecording = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceContinuousRecording);
    device8.continuousRecordingType = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceContinuousRecordingType);
    device8.loiteringDetection = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringDetection);
    device8.loiteringDetectionRange = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringDetectionRange);
    device8.loiteringDetectionLength = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringDetectionLength);
    device8.motionDetectionSensitivityMode = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityMode);
    device8.motionDetectionSensitivityStandard = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityStandard);
    device8.motionDetectionSensitivityAdvancedA = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedA);
    device8.motionDetectionSensitivityAdvancedB = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedB);
    device8.motionDetectionSensitivityAdvancedC = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedC);
    device8.motionDetectionSensitivityAdvancedD = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedD);
    device8.motionDetectionSensitivityAdvancedE = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedE);
    device8.motionDetectionSensitivityAdvancedF = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedF);
    device8.motionDetectionSensitivityAdvancedG = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedG);
    device8.motionDetectionSensitivityAdvancedH = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceMotionDetectionSensitivityAdvancedH);
    device8.loiteringCustomResponsePhoneNotification = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponsePhoneNotification);
    device8.loiteringCustomResponseAutoVoiceResponse = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponseAutoVoiceResponse);
    device8.loiteringCustomResponseAutoVoiceResponseVoice = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponseAutoVoiceResponseVoice);
    device8.loiteringCustomResponseHomeBaseNotification = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponseHomeBaseNotification);
    device8.loiteringCustomResponseTimeFrom = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponseTimeFrom);
    device8.loiteringCustomResponseTimeTo = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceLoiteringCustomResponseTimeTo);
    device8.deliveryGuard = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuard);
    device8.deliveryGuardPackageGuarding = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardPackageGuarding);
    device8.deliveryGuardPackageGuardingVoiceResponseVoice = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardPackageGuardingVoiceResponseVoice);
    device8.deliveryGuardPackageGuardingActivatedTimeFrom = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardPackageGuardingActivatedTimeFrom);
    device8.deliveryGuardPackageGuardingActivatedTimeTo = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardPackageGuardingActivatedTimeTo);
    device8.deliveryGuardUncollectedPackageAlert = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardUncollectedPackageAlert);
    device8.deliveryGuardUncollectedPackageAlertTimeToCheck = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardUncollectedPackageAlertTimeToCheck);
    device8.deliveryGuardPackageLiveCheckAssistance = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDeliveryGuardPackageLiveCheckAssistance);
    device8.dualCamWatchViewMode = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDualCamWatchViewMode);
    device8.ringAutoResponse = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingAutoResponse);
    device8.ringAutoResponseVoiceResponse = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingAutoResponseVoiceResponse);
    device8.ringAutoResponseVoiceResponseVoice = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingAutoResponseVoiceResponseVoice);
    device8.ringAutoResponseTimeFrom = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingAutoResponseTimeFrom);
    device8.ringAutoResponseTimeTo = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceRingAutoResponseTimeTo);
    device8.defaultAngle = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDefaultAngle);
    device8.defaultAngleIdleTime = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceDefaultAngleIdleTime);
    device8.soundDetectionRoundLook = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceSoundDetectionRoundLook);
    if (schemaVersion <= 10) {
        return device8;
    }
    // All schemas >= 11
    const device9 = device8;
    device9.imageMirrored = device.getPropertyValue(eufy_security_client_1.PropertyName.DeviceImageMirrored);
    return device9;
};
exports.dumpDevice = dumpDevice;
//# sourceMappingURL=state.js.map