"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TalkbackOnlyOneAtATimeError = exports.TalkbackNotRunningError = exports.TalkbackAlreadyRunningError = exports.DownloadOnlyOneAtATimeError = exports.DownloadNotRunningError = exports.DownloadAlreadyRunningError = exports.LivestreamNotRunningError = exports.LivestreamAlreadyRunningError = exports.SchemaIncompatibleError = exports.UnknownCommandError = exports.UnknownError = exports.BaseError = exports.ErrorCode = void 0;
var ErrorCode;
(function (ErrorCode) {
    ErrorCode["unknownError"] = "unknown_error";
    ErrorCode["unknownCommand"] = "unknown_command";
    ErrorCode["invalidCountryCode"] = "invalid_country_code";
    ErrorCode["invalidLanguageCode"] = "invalid_language_code";
    ErrorCode["stationNotFound"] = "station_not_found";
    ErrorCode["stationNotConnected"] = "station_not_connected";
    ErrorCode["stationConnectionTimeout"] = "station_connection_timeout";
    ErrorCode["deviceNotFound"] = "device_not_found";
    ErrorCode["deviceWrongStation"] = "device_wrong_station";
    ErrorCode["deviceInvalidProperty"] = "device_invalid_property";
    ErrorCode["deviceInvalidPropertyValue"] = "device_invalid_property_value";
    ErrorCode["devicePropertyNotSupported"] = "device_property_not_supported";
    ErrorCode["deviceReadOnlyProperty"] = "device_property_readonly";
    ErrorCode["deviceNotSupported"] = "device_not_supported";
    ErrorCode["deviceInvalidCommandValue"] = "device_invalid_command_value";
    ErrorCode["deviceLivestreamAlreadyRunning"] = "device_livestream_already_running";
    ErrorCode["deviceLivestreamNotRunning"] = "device_livestream_not_running";
    ErrorCode["schemaIncompatible"] = "schema_incompatible";
    ErrorCode["deviceDownloadAlreadyRunning"] = "device_download_already_running";
    ErrorCode["deviceDownloadNotRunning"] = "device_download_not_running";
    ErrorCode["deviceOnlyOneDownloadAtATime"] = "device_only_one_download_at_a_time";
    ErrorCode["deviceTalkbackAlreadyRunning"] = "device_talkback_already_running";
    ErrorCode["deviceTalkbackNotRunning"] = "device_talkback_not_running";
    ErrorCode["deviceOnlyOneTalkbackAtATime"] = "device_only_one_talkback_at_a_time";
    ErrorCode["deviceRTSPPropertyNotEnabled"] = "device_rtsp_property_not_enabled";
})(ErrorCode = exports.ErrorCode || (exports.ErrorCode = {}));
class BaseError extends Error {
}
exports.BaseError = BaseError;
class UnknownError extends BaseError {
    constructor(error) {
        super();
        this.error = error;
        this.errorCode = ErrorCode.unknownError;
    }
}
exports.UnknownError = UnknownError;
class UnknownCommandError extends BaseError {
    constructor(command) {
        super();
        this.command = command;
        this.errorCode = ErrorCode.unknownCommand;
    }
}
exports.UnknownCommandError = UnknownCommandError;
class SchemaIncompatibleError extends BaseError {
    constructor(schemaId) {
        super();
        this.schemaId = schemaId;
        this.errorCode = ErrorCode.schemaIncompatible;
    }
}
exports.SchemaIncompatibleError = SchemaIncompatibleError;
class LivestreamAlreadyRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = LivestreamAlreadyRunningError.name;
    }
}
exports.LivestreamAlreadyRunningError = LivestreamAlreadyRunningError;
class LivestreamNotRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = LivestreamNotRunningError.name;
    }
}
exports.LivestreamNotRunningError = LivestreamNotRunningError;
class DownloadAlreadyRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = DownloadAlreadyRunningError.name;
    }
}
exports.DownloadAlreadyRunningError = DownloadAlreadyRunningError;
class DownloadNotRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = DownloadNotRunningError.name;
    }
}
exports.DownloadNotRunningError = DownloadNotRunningError;
class DownloadOnlyOneAtATimeError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = DownloadOnlyOneAtATimeError.name;
    }
}
exports.DownloadOnlyOneAtATimeError = DownloadOnlyOneAtATimeError;
class TalkbackAlreadyRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = TalkbackAlreadyRunningError.name;
    }
}
exports.TalkbackAlreadyRunningError = TalkbackAlreadyRunningError;
class TalkbackNotRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = TalkbackNotRunningError.name;
    }
}
exports.TalkbackNotRunningError = TalkbackNotRunningError;
class TalkbackOnlyOneAtATimeError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = TalkbackOnlyOneAtATimeError.name;
    }
}
exports.TalkbackOnlyOneAtATimeError = TalkbackOnlyOneAtATimeError;
//# sourceMappingURL=error.js.map